@@ -22,7 +22,7 @@ plotter = DataPlotter(filePath)
 
 # calculate the difference of first columns
 #   start with 1, bc 0 is x value
-plotter.filterData(lambda l: l+ [l[2]-l[1]])
+plotter.filterData(lambda l: l+ [abs(l[2]-l[1])])
 
 # plot the data
 plotter.plot()
\ No newline at end of file
